@@ -1,20 +1,22 @@
 'use strict';
 
-const buildType = process.config.target_defaults.default_configuration;
 const assert = require('assert');
-const os = require('os');
+const { whichBuildType } = require('../common');
 
 const napiChild = require('../napi_child');
 
-module.exports = test(require(`../build/${buildType}/binding_noexcept_maybe.node`).maybe_check);
+module.exports = async function wrapTest () {
+  const buildType = await whichBuildType();
+  test(require(`../build/${buildType}/binding_noexcept_maybe.node`).maybe_check);
+};
 
-function test(binding) {
+function test (binding) {
   if (process.argv.includes('child')) {
     child(binding);
     return;
   }
   const cp = napiChild.spawn(process.execPath, [__filename, 'child'], {
-    stdio: ['ignore', 'inherit', 'pipe'],
+    stdio: ['ignore', 'inherit', 'pipe']
   });
   cp.stderr.setEncoding('utf8');
   let stderr = '';
@@ -31,8 +33,18 @@ function test(binding) {
   });
 }
 
-function child(binding) {
+function child (binding) {
+  const MAGIC_NUMBER = 12459062;
+  binding.normalJsCallback(() => {
+    return MAGIC_NUMBER;
+  }, MAGIC_NUMBER);
+
+  binding.testMaybeOverloadOp(
+    () => { return MAGIC_NUMBER; },
+    () => { throw Error('Foobar'); }
+  );
+
   binding.voidCallback(() => {
     throw new Error('foobar');
-  })
+  });
 }
