@@ -4,6 +4,6 @@ const assert = require('assert');
 
 module.exports = require('./common').runTest(test);
 
-function test(binding) {
-    assert.strictEqual(binding.memory_management.externalAllocatedMemory(), true)
+function test (binding) {
+  assert.strictEqual(binding.memory_management.externalAllocatedMemory(), true);
 }
