@@ -5,14 +5,14 @@ const testUtil = require('./testUtil');
 
 module.exports = require('./common').runTest(binding => test(binding.movable_callbacks));
 
-async function test(binding) {
+async function test (binding) {
   await testUtil.runGCTests([
     'External',
     () => {
       const fn = common.mustCall(() => {
         // noop
       }, 1);
-      const external = binding.createExternal(fn);
+      binding.createExternal(fn);
     },
     () => {
       // noop, wait for gc
