@@ -1,10 +1,10 @@
 #include <napi.h>
 
-class ConstructorExceptionTest :
-  public Napi::ObjectWrap<ConstructorExceptionTest> {
-public:
-  ConstructorExceptionTest(const Napi::CallbackInfo& info) :
-    Napi::ObjectWrap<ConstructorExceptionTest>(info) {
+class ConstructorExceptionTest
+    : public Napi::ObjectWrap<ConstructorExceptionTest> {
+ public:
+  ConstructorExceptionTest(const Napi::CallbackInfo& info)
+      : Napi::ObjectWrap<ConstructorExceptionTest>(info) {
     Napi::Error error = Napi::Error::New(info.Env(), "an exception");
 #ifdef NAPI_DISABLE_CPP_EXCEPTIONS
     error.ThrowAsJavaScriptException();
